<!-- AUTO-GENERATED: scripts/generate_explanation_fragments.py -->
### Model Method Hierarchy (Generated)

| Class | Description |
|---|---|
| `BaseModelMethod` | A base section used to define the abstract class of a Hamiltonian section. |
| `ModelMethod` | A base section for the method-defining choices of a simulation. |
| `ModelMethodElectronic` | A base section used to define the parameters of a model Hamiltonian used in electronic structure calculations (TB, DFT, GW, BSE, DMFT, etc). |

Source reference:
- [Model Method (Schema Navigation)](../../schema/model_method.md)
- [Model Method Electronic (Schema Navigation)](../../schema/model_method_electronic.md)
